@@ -28,6 +28,14 @@ test_that("Skipping detrending works", {
   expect_equal(detrend(1:10, trend = "assume_zero")$x, matrix(1:10))
 })
 
+test_that("non-numeric vector input leads to errors", {
+  expect_error(detrend(c(0, "0")),
+               regexp = "\'x\' must be numeric")
+  expect_error(get_noncentral_moments(c(10, 10), est = "local_consant",
+                                      bandwidth = 1, moment_number = 0.9),
+               regexp = "\'moment_number\' must be >= 1")
+})
+
 context("smoothing")
 
 test_that("Smoothing function works as expected", {
@@ -73,6 +81,15 @@ test_that("Smoothing function works as expected", {
                check.names = FALSE)
 })
 
+context("moment function")
+
+test_that("argument checking works", {
+            expect_error(get_noncentral_moments(c(0, "0")),
+                         regexp = "\'x\' must be numeric")
+
+          })
+
+
 context("smoothing arguments")
 
 test_that("invalid bandwidths lead to errors", {
@@ -294,7 +311,7 @@ test_that(paste("Estimate of stats consistent with other methods",
   times <- seq(0, 200, by = 1 / 12)
 
   sim <- create_simulator(params = params, times = times, covar = covar)
-  so <- pomp::simulate(sim, as.data.frame = TRUE, seed = 272)
+  so <- as(pomp::simulate(sim, seed = 272), "data.frame")
 
   bw <- 720
   n <- nrow(so)
